package com.fs.aiSipCall.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.aiSipCall.domain.AiSipCallPhone;
import com.fs.aiSipCall.dto.CallTaskStatModel;
import com.fs.aiSipCall.dto.CommonPhoneModel;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * aiSIP外呼通话记录Mapper接口
 * 
 * @author fs
 * @date 2026-03-06
 */
public interface AiSipCallPhoneMapper extends BaseMapper<AiSipCallPhone>{
    /**
     * 查询aiSIP外呼通话记录
     * 
     * @param id aiSIP外呼通话记录主键
     * @return aiSIP外呼通话记录
     */
    AiSipCallPhone selectAiSipCallPhoneById(String id);

    /**
     * 查询aiSIP外呼通话记录列表
     * 
     * @param aiSipCallPhone aiSIP外呼通话记录
     * @return aiSIP外呼通话记录集合
     */
    List<AiSipCallPhone> selectAiSipCallPhoneList(AiSipCallPhone aiSipCallPhone);

    /**
     * 新增aiSIP外呼通话记录
     * 
     * @param aiSipCallPhone aiSIP外呼通话记录
     * @return 结果
     */
    int insertAiSipCallPhone(AiSipCallPhone aiSipCallPhone);

    /**
     * 修改aiSIP外呼通话记录
     * 
     * @param aiSipCallPhone aiSIP外呼通话记录
     * @return 结果
     */
    int updateAiSipCallPhone(AiSipCallPhone aiSipCallPhone);

    /**
     * 删除aiSIP外呼通话记录
     * 
     * @param id aiSIP外呼通话记录主键
     * @return 结果
     */
    int deleteAiSipCallPhoneById(String id);

    /**
     * 批量删除aiSIP外呼通话记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAiSipCallPhoneByIds(String[] ids);
    /**
     * 根据batchId统计外呼数据
     * @param batchIds 任务ids
     * @return 结果
     */
    List<CallTaskStatModel> statByBatchIds(List<Long> batchIds);

    /**
     * 验证是否重复录入
     * @param batchId   任务Id
     * @param phoneList 电话号码
     * @return List<String> 重复的电话
     */
    @Select("<script>" +
            "SELECT DISTINCT telephone FROM ai_sip_call_phone " +
            "WHERE batch_id = #{batchId} " +
            "AND callstatus = 0 " +
            "AND STATUS = 0 " +
            "AND ( uuid = '' OR uuid IS NULL ) " +
            "AND telephone IN " +
            "<foreach item='phone' collection='phoneList' open='(' separator=',' close=')'>" +
            "#{phone.phoneNum}" +
            "</foreach>" +
            "</script>")
    List<String> isDuplicateEntry(@Param("batchId") Long batchId,@Param("phoneList")  List<CommonPhoneModel> phoneList);

    /**
     * 查询时间段内呼叫状态为待呼叫，没有通话uuid且数据正常的外呼记录
     * @return 外呼记录
     */
    @Select("SELECT * FROM ai_sip_call_phone " +
            "WHERE " +
            "callstatus = 0 " +
            "AND STATUS = 0 " +
            "AND ( uuid = '' OR uuid IS NULL ) " +
            "AND createtime >= #{startMillis} AND createtime <= #{endMillis}")
    List<AiSipCallPhone> selectCurrentDayCallRecords(@Param("startMillis") Long startMillis, @Param("endMillis") Long endMillis);

    @Update("<script>" +
            "update ai_sip_call_phone set status = 1 where local_batch_id in " +
            "<foreach collection='batchIds' item='id' open='(' separator=',' close=')'>" +
            "#{id}" +
            "</foreach>" +
            "</script>")
    int logicalDeletionByBatchIds(@Param("batchIds") Long[] batchIds);
}
